export declare class Table {
  /** zero-based index of the column that should be fixed on smaller viewports - defaults to the first col */
  fixedColIndex: number;
  /** maximum number of pixels that the fixed column is allowed to be wide */
  maxFixedColWidth: number;
  /** the table should always be at least 100% wide */
  fullWidth: boolean;
  /** the table should sort its static data by itself. Do not use this if the data needs to be sorted by some logic (i.e. via an API) */
  sortable: boolean;
  /** The link in the last column will be added into the fixed column on smaller viewports */
  hasFixedLink: boolean;
  /** is true when the table is horizontally scrollable (has a fixed col) */
  isFixed: boolean;
  /** width of the fixed col */
  fixedColWidth: number;
  /** the left shadow is visible */
  leftShadow: boolean;
  /** the right shadow is visible */
  rightShadow: boolean;
  /** unique ID used to style this instance via style tag */
  uniqueId: string;
  /** checks for IE11 for IntersectionObserver support */
  private supportsIntersectionObserver;
  /** if hasFixedLink is active, we need to add more width to the fixed cell,
   * but only once. Once this flag is set to true, this addition will not be
   * performed, avoiding useless space being added in the table cells.
   */
  fixedLinkSpaceAdded: boolean;
  /** the fixed column should have a min width set to fit-content to prevent being
   * calculated too small, but if the content of the column exceeds the maximun width
   * of the column specified via prop, then the min-width should be set to auto.
   */
  fixedColumnHasMinWidth: boolean;
  element: HTMLUxTableElement;
  private contentObserver;
  private handleIntersection;
  private intersectionObserver;
  private table;
  private innerDiv;
  connectedCallback(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  private onContentChange;
  private onResize;
  private calculateTableState;
  private calculateFixedColWidth;
  private onScroll;
  private calculateShadows;
  /** the height of multi-line cells might differ from the fixed cell, so we need to sync it to prevent gaps */
  private syncRowHeight;
  sortRows(e: Event): void;
  private addFixedLink;
  render(): any;
}
